#
# spec file for package shaderc
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           shaderc
%define lname libshaderc_shared1
Version:        2019.1
Release:        1.26
Summary:        A collection of tools, libraries and tests for shader compilation
License:        Apache-2.0
Group:          Development/Tools/Other
URL:            https://github.com/google/shaderc

#Git-Clone:	https://github.com/google/shaderc
Source:         https://github.com/google/shaderc/archive/v%version.tar.gz
Patch1:         0001-Use-system-third-party-libs.patch
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  glslang-devel >= 7
BuildRequires:  python-xml
BuildRequires:  spirv-headers >= 1.4
BuildRequires:  spirv-tools-devel > 2019.3

%description
A collection of tools, libraries and tests for shader compilation.
At the moment, included are:

* glslc, a command line compiler for GLSL/HLSL to SPIR-V, and
* libshaderc, a library API for doing the same.

Shaderc wraps around core functionality in glslang and SPIRV-Tools.

%package -n %lname
Summary:        SPIR-V shader compiler library
Group:          System/Libraries

%description -n %lname
A compiler library for GLSL/HLSL to SPIR-V.

Shaderc wraps around core functionality in glslang and SPIRV-Tools

%package devel
Summary:        Header files for the shaderc library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
A compiler library for GLSL/HLSL to SPIR-V.

Shaderc wraps around core functionality in glslang and SPIRV-Tools

%prep
%autosetup -p1
echo "\"%{version}\"" > glslc/src/build-version.inc

%build
%cmake -DSHADERC_SKIP_TESTS=ON
%make_jobs

%install
%cmake_install
rm %buildroot/%_libdir/*.a

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%license LICENSE
%_bindir/glslc

%files -n %lname
%_libdir/libshaderc_shared.so.1*

%files devel
%_includedir/shaderc/
%_libdir/libshaderc_shared.so
%_libdir/pkgconfig/*.pc

%changelog
* Mon Feb 17 2020 jengelh@inai.de
- Update to release 2019.1
  * Vulkan 1.2 support
  * Add spvc parser support for a number of ops
- Drop 0001-Force-Glslang-to-support-HLSL-in-its-interface-784.patch
* Tue Nov 19 2019 jengelh@inai.de
- Add 0001-Force-Glslang-to-support-HLSL-in-its-interface-784.patch
* Wed Jun  5 2019 jengelh@inai.de
- Update to new upstream release 2019.0
  * Add optional spvc, libshaderc_spvc as wrapper around
    SPIRV-Cross.
  * Support NV extensions for shader stages.
  * spvc: Added option to specify source environment. Spvc will
    transform from source to target environment if they are
    different. This only works for WebGPU0 and Vulkan 1.1.
* Fri Dec 14 2018 jengelh@inai.de
- Update to new upstream release 2018.0
  * Support -fhlsl_functionality1 (also -fhlsl-functionality1)
  * Support NVIDIA Turing extensions. Requires updated Glslang
    and SPIRV-Tools.
  * Use SPIR-V optimization and HLSL legalization recipes from
    SPIRV-Tools.
  * Pass target environment into SPIRV-Tools code, e.g. from
  - -target-env vulkan1.1 .
* Sat Mar 31 2018 9+suse@cirno.systems
- Update to version 20180329.g2a0f3a3:
  * Use standard SPIRV-Tools transformation recipes
  * Locate clang for Linux buildbots. (#446)
  * Support setting target environment version, e.g. Vulkan 1.1
  * Re-enable the Windows continuous Debug builds. (#444)
  * Add build result badges to README. (#439)
  * Glslang generator version 6
  * Glslang generator version 5
  * Update glslc README for -fauto-map-locations
  * Add glslc tests for -fauto-map-locations
  * Fix setting of debug DLL name for AppVeyor
  * Adding kokoro build configurations. (#429)
  * AppVeyor packaging: debug DLL name no longer has extra "d"
  * Start v2018.0-dev
  * Finalize v2017.2
  * copyright check: Skip auto-generated CMakeFiles
  * Update CHANGES for -fauto-map-locations
  * Glslang now requires bindings on resources
  * Add -fauto-map-locations option
* Fri Feb 23 2018 9+suse@cirno.systems
- Update to version 20180207.g563bc6e:
  * Add a virtual destructor, otherwise Clang 6.0complains about delete being called on an abstract class.
  * Skip Debug builds for VS 2013 and VS 2015
  * Glslang updated its generator version number to 4
  * Android.mk: add glslang/MachineIndependent/attribute.cpp
  * Make tests resilient to better SPIR-V optimizations
  * Travis CI: install pip and set clone depth to 1
  * Adapt to Glslang codegen version update
* Thu Nov 23 2017 9@cirno.systems
- Update to version 20171030.g98ab88b:
  * glslc tests: Relax version word check
  * Avoid -fPIC for MinGW builds
  * Allow override of SPVTOOLS_LOCAL_PATH
  * Move spirv-tools build from third_party/Android.mk
  * Update CHANGES
  * Adapt to Glslang generator version number change
  * Travis CI: use make to build
  * Add HLSL legalization passes to compiler.cc
  * Add SPIRV-Tools optimizer files for linker
  * Added more opt passes to PassId enum
* Wed Nov 22 2017 9@cirno.systems
- Re-add explicit version dependencies
* Mon Nov 20 2017 9@cirno.systems
- Drop explicit version dependency on spirv-tools
* Fri Nov  3 2017 9@cirno.systems
- init
